summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/GraphObjectImpl.hpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-10-08 17:59:56 +0000
committerDavid Robillard <d@drobilla.net>2007-10-08 17:59:56 +0000
commit91ca84684151a67b8e3e1e859b3167e9f687d4d4 (patch)
tree1751b6e4949b47d1880b4c569b6192fef392bfaf /src/libs/engine/GraphObjectImpl.hpp
parent507d9ffa4771978b6964b4c4b261ee923ba7e324 (diff)
downloadingen-91ca84684151a67b8e3e1e859b3167e9f687d4d4.tar.gz
ingen-91ca84684151a67b8e3e1e859b3167e9f687d4d4.tar.bz2
ingen-91ca84684151a67b8e3e1e859b3167e9f687d4d4.zip
s/MetadataMap/Variables/ etc.
Removed ancient/unused Controller.hpp. git-svn-id: http://svn.drobilla.net/lad/ingen@852 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/libs/engine/GraphObjectImpl.hpp')
-rw-r--r--src/libs/engine/GraphObjectImpl.hpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/libs/engine/GraphObjectImpl.hpp b/src/libs/engine/GraphObjectImpl.hpp
index 1793366e..3862c762 100644
--- a/src/libs/engine/GraphObjectImpl.hpp
+++ b/src/libs/engine/GraphObjectImpl.hpp
@@ -42,7 +42,7 @@ class ProcessContext;
/** An object on the audio graph - Patch, Node, Port, etc.
*
* Each of these is a Raul::Deletable and so can be deleted in a realtime safe
* way from anywhere, and they all have a map of metadata for clients to store
* arbitrary values in (which the engine puts no significance to whatsoever).
*
* \ingroup engine
@@ -67,16 +67,16 @@ public:
assert(_name.find("/") == string::npos);
}
- void set_metadata(const string& key, const Atom& value)
- { _metadata[key] = value; }
+ void set_variable(const string& key, const Atom& value)
+ { _variables[key] = value; }
- const Atom& get_metadata(const string& key) {
+ const Atom& get_variable(const string& key) {
static Atom null_atom;
- MetadataMap::iterator i = _metadata.find(key);
- return (i != _metadata.end()) ? (*i).second : null_atom;
+ Variables::iterator i = _variables.find(key);
+ return (i != _variables.end()) ? (*i).second : null_atom;
}
- const MetadataMap& metadata() const { return _metadata; }
+ const Variables& variables() const { return _variables; }
/** The Patch this object is a child of. */
virtual PatchImpl* parent_patch() const;
@@ -109,7 +109,7 @@ protected:
bool _polyphonic;
private:
- MetadataMap _metadata;
+ Variables _variables;
};
@@ -42,7 +42,7 @@ class ProcessContext;
*
* Each of these is a Raul::Deletable and so can be deleted in a realtime safe
- * way from anywhere, and they all have a map of metadata for clients to store
+ * way from anywhere, and they all have a map of variable for clients to store
* arbitrary values in (which the engine puts no significance to whatsoever).
*